@@ -6,7 +6,6 @@ use warnings;
 use English qw(-no_match_vars);
 use UNIVERSAL::require;
 use URI;
-use HTTP::Status;
 
 =head1 NAME
 
@@ -40,9 +39,7 @@ use FusionInventory::Compress;
 sub new {
     my ($class, $params) = @_;
 
-    my $self = {
-        defaultTimeout => 180
-    };
+    my $self = {};
 
     $self->{accountinfo} = $params->{accountinfo}; # Q: Is that needed?
 
@@ -96,33 +93,7 @@ sub createUA {
     $logger->fault("Unsupported protocol $protocol")
         unless $protocol eq 'http' or $protocol eq 'https';
 
-    if ($config->{'no-ssl-check'}) {
-        if (!$config->{SslCheckWarningShown}) {
-            $logger->info( "--no-ssl-check parameter "
-                . "found. Don't check server identity!!!" );
-            $config->{SslCheckWarningShown} = 1;
-        }
-    }
-
-
-    my $ua = LWP::UserAgent->new(keep_alive => 1, requests_redirectable => ['POST', 'GET', 'HEAD']);
-
-    # previously this block was only for LWP6.
-    # For some modern LWP5/Crypt::SSLeay also need it, I use
-    # an eval here to avoid failure on ancient LWP::UserAgent with
-    # no ssl_opts()
-    eval {
-        # LWP6 default behavior is to check the SSL hostname
-        if ($config->{'no-ssl-check'}) {
-            $ua->ssl_opts(verify_hostname => 0);
-        }
-        if ($config->{'ca-cert-file'}) {
-            $ua->ssl_opts(SSL_ca_file => $config->{'ca-cert-file'});
-        }
-        if ($config->{'ca-cert-dir'}) {
-            $ua->ssl_opts(SSL_ca_path => $config->{'ca-cert-dir'});
-        }
-    };
+    my $ua = LWP::UserAgent->new(keep_alive => 1);
 
     if ($noProxy) {
 
@@ -222,42 +193,24 @@ sub send {
     $req->content($compressed);
 
     my $ua = $self->createUA({URI => $self->{URI}});
-    my $res;
-    eval {
-        if ($^O =~ /^MSWin/ && $self->{URI} =~ /^https:/g) {
-            alarm $self->{defaultTimeout};
-        }
-        $res = $ua->request($req);
-        alarm 0;
-    };
+    my $res = $ua->request($req);
 
-
-    my $serverRealm;
-    if ($res && $res->code == '401' && $res->header('www-authenticate') =~ /^Basic realm="(.*)"/ && !$self->{config}->{realm}) {
-        $serverRealm = $1;
-        $logger->debug("Basic HTTP Auth: fixing the realm to '$serverRealm' and retrying.");
+    if ($res->code == '401' && $res->header('www-authenticate') =~ /^Basic realm="(.*)"/ && !$self->{config}->{realm}) {
+        my $serverRealm = $1;
+        $logger->debug("Basic HTTP Auth: fixing the realm to '$serverRealm' and retry.");
 
         $ua = $self->createUA({URI => $self->{URI}, forceRealm => $serverRealm});
-        eval {
-            if ($^O =~ /^MSWin/ && $self->{URI} =~ /^https:/g) {
-                alarm $self->{defaultTimeout};
-            }
-            $res = $ua->request($req);
-            alarm 0;
-        }
+        $res = $ua->request($req);
     }
 
     # Checking if connected
-    if(!$res || !$res->is_success) {
+    if(!$res->is_success) {
         $logger->error ('Cannot establish communication with `'.
             $self->{URI}.': '.
-            (($res && $res->status_line) || 'Internal error' ).'`');
+            $res->status_line.'`');
         return;
     }
 
-    # Ok we found the correct realm. We store it.
-    $self->{config}->{realm} = $serverRealm if $serverRealm;
-
     # stop or send in the http's body
 
     my $content = '';
@@ -265,10 +218,7 @@ sub send {
     if ($res->content) {
         $content = $compress->uncompress($res->content);
         if (!$content) {
-            $logger->error ("Deflating problem. Is the string really ".
-            "compressed? Do you use the correct URL to the server. ".
-            "The string start with: ".substr($res->content, 0, 500));
-
+            $logger->error ("Deflating problem");
             return;
         }
     }
@@ -302,14 +252,20 @@ sub turnSSLCheckOn {
     my $config = $self->{config};
 
 
-    return if $config->{'no-ssl-check'};
+    if ($config->{'no-ssl-check'}) {
+        if (!$config->{SslCheckWarningShown}) {
+            $logger->info( "--no-ssl-check parameter "
+                . "found. Don't check server identity!!!" );
+            $config->{SslCheckWarningShown} = 1;
+        }
+        return;
+    }
 
     if (!$config->{'ca-cert-file'} && !$config->{'ca-cert-dir'}) {
-        $logger->debug("You may need to use either --ca-cert-file ".
+        $logger->fault("You need to use either --ca-cert-file ".
             "or --ca-cert-dir to give the location of your SSL ".
             "certificat. You can also disable SSL check with ".
             "--no-ssl-check but this is very unsecure.");
-        return;
     }
 
 
@@ -320,7 +276,6 @@ sub turnSSLCheckOn {
         }
 
         $ENV{HTTPS_CA_FILE} = $config->{'ca-cert-file'};
-        $ENV{PERL_LWP_SSL_CA_FILE} = $config->{'ca-cert-file'};
 
     } elsif ($config->{'ca-cert-dir'}) {
         if (!-d $config->{'ca-cert-dir'}) {
@@ -328,8 +283,7 @@ sub turnSSLCheckOn {
                 "`".$config->{'ca-cert-dir'}."'");
         }
 
-        $ENV{HTTPS_CA_DIR} = $config->{'ca-cert-dir'};
-        $ENV{PERL_LWP_SSL_CA_PATH} = $config->{'ca-cert-dir'};
+        $ENV{HTTPS_CA_DIR} =$config->{'ca-cert-dir'};
 
     }
 
@@ -355,21 +309,13 @@ sub setSslRemoteHost {
     if ($self->{URI} !~ /^https:/i) {
         return;
     }
+    $self->turnSSLCheckOn();
 
-# Compatibility with LWP5
-    if ($LWP::VERSION < 6) {
-        $self->turnSSLCheckOn();
     # Check server name against provided SSL certificate
-        if ( $self->{URI} =~ /^https:\/\/([^\/]+).*$/i ) {
-            my $re = $1;
-            $re =~ s/:\d+//;
-# Accept SSL cert will hostname with wild-card
-# http://forge.fusioninventory.org/issues/542
-            $re =~ s/^([^\.]+)/($1|\\*)/;
-# protect some characters, $re will be evaluated as a regex
-            $re =~ s/([\-\.])/\\$1/g;
-            $ua->default_header('If-SSL-Cert-Subject' => '/CN='.$re.'($|\/)');
-        }
+    if ( $self->{URI} =~ /^https:\/\/([^\/]+).*$/i ) {
+        my $cn = $1;
+        $cn =~ s/([\-\.])/\\$1/g;
+        $ua->default_header('If-SSL-Cert-Subject' => '/CN='.$cn);
     }
 }
 
@@ -403,16 +349,8 @@ sub getStore {
 
     $ua->timeout($timeout) if $timeout;
 
-    my $response;
-    eval {
-        if ($^O =~ /^MSWin/ && $source =~ /^https:/g) {
-            alarm $self->{defaultTimeout};
-        }
-
-        my $request = HTTP::Request->new(GET => $source);
-        $response = $ua->request($request, $target);
-        alarm 0;
-    };
+    my $request = HTTP::Request->new(GET => $source);
+    my $response = $ua->request($request, $target);
 
     return $response->code;
 
