@@ -93,8 +93,13 @@ sub handler {
     }
 
 
-    $logger->debug("[RPC] $clientIp request ".$r->uri->path);
+    $logger->debug("[RPC ]$clientIp request ".$r->uri->path);
     if ($r->method eq 'GET' and $r->uri->path =~ /^\/$/) {
+        if ($clientIp !~ /^127\./) {
+            $c->send_error(404);
+            return;
+        }
+
         my $nextContact = "";
         foreach my $target (@{$targets->{targets}}) {
             my $path = $target->{'path'};
@@ -122,7 +127,7 @@ sub handler {
         $output =~ s/%%STATUS%%/$status/;
         $output =~ s/%%NEXT_CONTACT%%/$nextContact/;
         $output =~ s/%%AGENT_VERSION%%/$config->{VERSION}/;
-        if ($clientIp !~ /^127\./ || !$config->{'rpc-trust-localhost'}) {
+        if (!$config->{'rpc-trust-localhost'}) {
             $output =~
             s/%%IF_ALLOW_LOCALHOST%%.*%%ENDIF_ALLOW_LOCALHOST%%//;
         }
@@ -152,7 +157,7 @@ sub handler {
         my $currentToken = $self->getToken();
         my $code;
         my $msg;
-        $logger->debug("[RPC] 'now' catched");
+        $logger->debug("[RPC]'now' catched");
         if (
             ($config->{'rpc-trust-localhost'} && $clientIp =~ /^127\./)
                 or
@@ -167,7 +172,7 @@ sub handler {
 
             $logger->debug("[RPC] bad token $sentToken != ".$currentToken);
             $code = 403;
-            $msg = "Access denied. You are not using the 127.0.0.1 IP address to access the server or rpc-trust-localhost is off or the token is invalid."
+            $msg = "Access denied. rpc-trust-localhost is off or the token is invalide."
 
         }
 
@@ -193,7 +198,7 @@ sub handler {
         /^\/(logo.png|site.css|favicon.ico)$/) {
         $c->send_file_response($htmlDir."/$1");
     } else {
-        $logger->debug("[RPC] Err, 500");
+        $logger->debug("[RPC]Err, 500");
         $c->send_error(500)
     }
     $c->close;
@@ -212,13 +217,13 @@ sub server {
     if ($config->{'rpc-ip'}) {
         $daemon = $self->{daemon} = HTTP::Daemon->new(
             LocalAddr => $config->{'rpc-ip'},
-            LocalPort => $config->{'rpc-port'} || 62354,
+            LocalPort => 62354,
             Reuse     => 1,
             Timeout   => 5
         );
     } else {
         $daemon = $self->{daemon} = HTTP::Daemon->new(
-            LocalPort => $config->{'rpc-port'} || 62354,
+            LocalPort => 62354,
             Reuse     => 1,
             Timeout   => 5
         );
@@ -228,10 +233,7 @@ sub server {
         $logger->error("Failed to start the RPC server");
         return;
     } 
-    $logger->info("RPC service started at: http://".
-        ( $config->{'rpc-ip'} || "127.0.0.1" ).
-        ":".
-        $config->{'rpc-port'} || 62354);
+    $logger->info("RPC service started at: ". $daemon->url);
 
 # Since perl 5.10, threads::joinable is avalaible
     my $joinableAvalaible = eval 'defined(threads::joinable) && 1';
@@ -308,13 +310,13 @@ FusionInventory::Agent::RPC - the RPC interface
 =head1 DESCRIPTION
 
 FusionInventory Agent can listen on the network through an embedded HTTP
-server. This server can only be used to wakeup the agent or download
+server. This server can only be used to wakeup the agent of download
 OcsDeploy cached files. The server uses port 62354.
 
-Every time the agent contact the server, it send a token, this token will
+Every time the agent contact the server, it pushs a token, this token will
 be needed to identify the server who want to awake an agent.
 
-Once an agent is awake, it will contact the server as usual to know
+Once an agent is awake, its agent will contact the server as usual to know
 the jobs it need to do.
 
 =head1 SYNOPSIS
