@@ -19,8 +19,7 @@ sub new {
     });
     $self->{storage} = $storage;
     $self->{data} = $data;
-    my $myCaller = scalar(caller(0));
-    $self->{myData} = $storage->restore({ module => $myCaller  });
+    $self->{myData} = $storage->restore();
 
     $self->{config} = $data->{config};
     $self->{target} = $data->{target};
