@@ -53,7 +53,7 @@ sub _ipdhcp {
         }
         close $handle or warn;
         chomp (my $currenttime = `date +"%Y%m%d%H%M%S"`);
-        undef $ipdhcp unless $expire && ($currenttime <= $expire);
+        undef $ipdhcp unless $currenttime <= $expire;
     } else {
         warn "Can't open $leasepath\n";
     }
@@ -100,7 +100,7 @@ sub doInventory {
     # for each interface get it's parameters
     foreach my $description (@list) {
         $ipaddress = $ipmask = $macaddr = $status =  $type = $mtu = "";
-        $virtualdev = undef;
+        $virtualdev = "no";
         # search interface infos
         @ifconfig = `ifconfig $description`;
         foreach (@ifconfig){
@@ -118,13 +118,9 @@ sub doInventory {
         my $binsubnet = $binip & $binmask;
         $ipsubnet = ip_bintoip($binsubnet,4);
 
-        if ($ipmask =~ /^0x(\w{2})(\w{2})(\w{2})(\w{2})$/) {
-             $ipmask = hex($1).'.'.hex($2).'.'.hex($3).'.'.hex($4);
-        }
-
         $_ = $description;
         if (/^(lo|vboxnet|vmnet|tun)\d+/) {
-            $virtualdev = 1;
+            $virtualdev = "yes";
         }
 
         $inventory->addNetwork({
