@@ -16,7 +16,7 @@ sub doInventory {
 
     if (open my $handle, '<', '/etc/fstab') {
         while(<$handle>){
-            if(/^\/dev\/(\S+)/) {
+            if(/^\/dev\/(\D+\d)/) {
                 push @devices, $1 unless grep(/^$1$/, @devices);
             }
         }
@@ -32,16 +32,14 @@ sub doInventory {
             if(/^$dev.*\s+(\d+)\s*MB/) { $capacity = $1;}
         }
 
-        if ($model) {
-            if ($model =~ s/^(SGI|SONY|WDC|ASUS|LG|TEAC|SAMSUNG|PHILIPS|PIONEER|MAXTOR|PLEXTOR|SEAGATE|IBM|SUN|SGI|DEC|FUJITSU|TOSHIBA|YAMAHA|HITACHI|VERITAS)\s*//i) {
-                $manufacturer = $1;
-            }
-
-            # clean up the model
-            $model =~ s/^(\s|,)*//;
-            $model =~ s/(\s|,)*$//;
+        if ($model =~ s/^(SGI|SONY|WDC|ASUS|LG|TEAC|SAMSUNG|PHILIPS|PIONEER|MAXTOR|PLEXTOR|SEAGATE|IBM|SUN|SGI|DEC|FUJITSU|TOSHIBA|YAMAHA|HITACHI|VERITAS)\s*//i) {
+            $manufacturer = $1;
         }
 
+        # clean up the model
+        $model =~ s/^(\s|,)*//;
+        $model =~ s/(\s|,)*$//;
+
         $inventory->addStorages({
             MANUFACTURER => $manufacturer,
             MODEL => $model,
