@@ -1,6 +1,9 @@
 package FusionInventory::Agent::Task::Inventory::OS::Linux::Archs::ARM::CPU;
 
 use strict;
+use warnings;
+
+use English qw(-no_match_vars);
 
 sub isInventoryEnabled { can_read("/proc/cpuinfo") }
 
@@ -8,11 +11,16 @@ sub doInventory {
     my $params = shift;
     my $inventory = $params->{inventory};
 
+    my $handle;
+    if (!open $handle, '<', '/proc/cpuinfo') {
+        warn "Can't open /proc/cpuinfo: $ERRNO";
+        return;
+    }
+
     my @cpu;
     my $current;
-    open CPUINFO, "</proc/cpuinfo" or warn;
-    foreach(<CPUINFO>) {
-        print;
+
+    while (<$handle>) {
         if (/^Processor\s+:\s*:/) {
 
             if ($current) {
@@ -24,13 +32,12 @@ sub doInventory {
             };
 
         }
-
         $current->{TYPE} = $1 if /Processor\s+:\s+(\S.*)/;
-
     }
+    close $handle;
 
     # The last one
     $inventory->addCPU($current);
 }
 
-1
+1;
