@@ -49,7 +49,7 @@ sub getFromDF {
 
     my %months = (
         Jan => 1,
-        Feb => 2,
+        Fev => 2,
         Mar => 3,
         Apr => 4,
         May => 5,
@@ -136,12 +136,11 @@ sub parseLshal {
         return;
     }
 
-   my $devices = [];
-   my $device = {};
+   my ($devices, $device);
 
     while (my $line = <$handle>) {
         chomp $line;
-        if ($line =~ m{^udi = '/org/freedesktop/Hal/devices/(volume|block).*}) {
+        if ($line =~ m{^udi = '/org/freedesktop/Hal/devices/volume.*}) {
             $device = {};
             next;
         }
@@ -149,10 +148,7 @@ sub parseLshal {
         next unless defined $device;
 
         if ($line =~ /^$/) {
-            if ($device->{ISVOLUME}) {
-                delete($device->{ISVOLUME});
-                push(@$devices, $device);
-            }
+            push(@$devices, $device);
             undef $device;
         } elsif ($line =~ /^\s+ block.device \s = \s '([^']+)'/x) {
             $device->{VOLUMN} = $1;
@@ -167,8 +163,6 @@ sub parseLshal {
          } elsif ($line =~ /^\s+ volume.size \s = \s (\S+)/x) {
             my $value = $1;
             $device->{TOTAL} = int($value/(1024*1024) + 0.5);
-        } elsif ($line =~ /block.is_volume\s*=\s*true/i) {
-            $device->{ISVOLUME} = 1;
         }
     }
     close $handle;
