@@ -39,7 +39,7 @@ sub getFromSysProc {
         push(@names, $1);
     }
 
-    my $command = `fdisk -v` =~ '^GNU' ? 'fdisk -p -l 2>&1' : 'fdisk -l 2>&1';
+    my $command = `fdisk -v` =~ '^GNU' ? 'fdisk -p -l' : 'fdisk -l';
     if (!open my $handle, '-|', $command) {
         warn "Can't run $command: $ERRNO";
     } else {
@@ -101,10 +101,8 @@ sub getCapacity {
     my ($dev) = @_;
     my $command = `/sbin/fdisk -v` =~ '^GNU' ? 'fdisk -p -s' : 'fdisk -s';
     # requires permissions on /dev/$dev
-    my $cap;
-    foreach (`$command /dev/$dev 2>/dev/null`) {
-        $cap = $1 if /^\d+$/;
-    }
+    my $cap = `$command /dev/$dev 2>/dev/null`;
+    chomp $cap;
     $cap = int($cap / 1000) if $cap;
     return $cap;
 }
@@ -117,13 +115,7 @@ sub getDescription {
     return "USB" if (defined ($description) && $description =~ /usb/i);
 
     if ($name =~ /^s/) { # /dev/sd* are SCSI _OR_ SATA
-        if (
-	($manufacturer && ($manufacturer =~ /ATA/))
-	||
-	($serialnumber && ($serialnumber =~ /ATA/))
-	||
-	($description && ($description =~ /ATA/))
-	) {
+        if (($manufacturer && ($manufacturer =~ /ATA/)) || ($serialnumber && ($serialnumber =~ /ATA/))) {
             return  "SATA";
         } else {
             return "SCSI";
@@ -209,19 +201,13 @@ sub doInventory {
                         if !$device->{SERIALNUMBER};
                         next;
                     }
-                    elsif ($line =~ /^\s+Firmware Revision\s*:\s*(.+)/i) {
+                    if ($line =~ /^\s+Firmware Revision\s*:\s*(.+)/i) {
                         my $value = $1;
                         $value =~ s/\s+$//;
                         $device->{FIRMWARE} = $value
                         if !$device->{FIRMWARE};
                         next;
                     }
-		    elsif ($line =~ /^\s*Transport:.*(SCSI|SATA|USB)/) {
-			$device->{DESCRIPTION} = $1;
-		    }
-		    elsif ($line =~ /^\s*Model Number:\s*(.*?)\s*$/) {
-			$device->{MODEL} = $1;
-		    }
                 }
                 close $handle;
             }
@@ -229,21 +215,19 @@ sub doInventory {
     }
 
     foreach my $device (@devices) {
-	if (!$device->{DESCRIPTION}) {
         $device->{DESCRIPTION} = getDescription(
             $device->{NAME},
             $device->{MANUFACTURER},
             $device->{DESCRIPTION},
             $device->{SERIALNUMBER}
-            );
-	}
+        );
 
         if (!$device->{MANUFACTURER} or $device->{MANUFACTURER} eq 'ATA') {
             $device->{MANUFACTURER} = getManufacturer($device->{MODEL});
         }
 
-        if (!$device->{DISKSIZE} && $device->{TYPE} !~ /^cd/) {
-            $device->{DISKSIZE} = getCapacity($device->{NAME});
+        if ($device->{CAPACITY} && $device->{CAPACITY} =~ /^cd/) {
+            $device->{CAPACITY} = getCapacity($device->{NAME});
         }
 
         $inventory->addStorage($device);
@@ -289,6 +273,9 @@ sub parseUdev {
         $result->{SERIALNUMBER} = $serial
     }
 
+    $result->{DISKSIZE} = getCapacity($device)
+    if $result->{TYPE} ne 'cd';
+
     $result->{NAME} = $device;
 
     return $result;
@@ -304,8 +291,7 @@ sub parseLshal {
         return;
     }
 
-    my $devices = [];
-    my $device = {};
+    my ($devices, $device);
 
     while (my $line = <$handle>) {
         chomp $line;
@@ -317,11 +303,8 @@ sub parseLshal {
         next unless defined $device;
 
         if ($line =~ /^$/) {
-            if (keys %$device && defined($device->{ISVOLUME}) && !$device->{ISVOLUME}) {
-                delete($device->{ISVOLUME});
-                push(@$devices, $device);
-                undef $device;
-            }
+            push(@$devices, $device);
+            undef $device;
         } elsif ($line =~ /^\s+ storage.serial \s = \s '([^']+)'/x) {
             $device->{SERIALNUMBER} = $1;
         } elsif ($line =~ /^\s+ storage.firmware_version \s = \s '([^']+)'/x) {
@@ -338,9 +321,7 @@ sub parseLshal {
         } elsif ($line =~ /^\s+ storage.size \s = \s (\S+)/x) {
             my $value = $1;
             $device->{DISKSIZE} = int($value/(1024*1024) + 0.5);
-        } elsif ($line =~ /block.is_volume\s*=\s*false/i) {
-           $device->{ISVOLUME} = 0;
-       }
+        }
     }
     close $handle;
 
