@@ -19,7 +19,6 @@ my %unitMatrice = (
     Mi => 1,
     MB => 1,
     Ki => 0.001,
-    KB => 0.001,
 );
 
 sub doInventory {
@@ -38,8 +37,7 @@ sub doInventory {
 
     my %fs;
     foreach (`mount`) {
-	next if /^devfs/;
-	next if /^fdesc/;
+        next unless /^\//;
         if (/on\s.+\s\((\S+?)(,|\))/) {
             $fs{$1} = 1;
         }
@@ -48,7 +46,7 @@ sub doInventory {
     for my $t (keys %fs) {
         # OpenBSD has no -m option so use -k to obtain results in kilobytes
         for(`df -P -k -t $t`){ # darwin needs the -t to be last
-            if(/^(\/\S*)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\n/){
+            if(/^(\/\S*)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S.+)\n/){
                 $type = $6;
                 $filesystem = $t;
                 $total = sprintf("%i",$2/1024);
@@ -82,8 +80,7 @@ sub doInventory {
 
         my $isHardDrive;
 
-        if ((defined($device->{'Part Of Whole'}) && ($device->{'Part Of Whole'} eq $device->{'Device Identifier'}))) {
-            # Is it possible to have a drive without partition?
+        if ($device->{'Part Of Whole'} eq $device->{'Device Identifier'}) {
             $isHardDrive = 1;
         }
 
@@ -98,7 +95,7 @@ sub doInventory {
 
         if (!$isHardDrive) {
             $drives{$deviceName}->{TOTAL} = $size;
-            $drives{$deviceName}->{SERIAL} = $device->{'Volume UUID'} || $device->{'UUID'};
+            $drives{$deviceName}->{SERIAL} = $device->{'Volume UUID'};
             $drives{$deviceName}->{FILESYSTEM} = $device->{'File System'} || $device->{'Partition Type'};
             $drives{$deviceName}->{VOLUMN} = $deviceName;
             $drives{$deviceName}->{LABEL} = $device->{'Volume Name'};
