@@ -22,6 +22,8 @@ sub isInventoryEnabled {
 sub doInventory {
     my $params = shift;
     my $inventory = $params->{inventory};
+    my $localperl;
+    my $libperl;
     my $description;
     my $ipaddress;
     my $ipgateway;
@@ -135,10 +137,21 @@ sub doInventory {
 # Function to test a Intel 82571-based ethernet controller port (i.e. ipge_).
     sub check_ce {
         my ($mynic,$mynum) = @_;
+        #/usr/perl5/5.00503/bin/perl
+        #foreach (`which perl`){
+        #$localperl = $1 if /^(\S+)/;
+        #	$libperl = "/".$1."/".$2."/".$3."/bin/perl" if /^\/(\S+)\/(\S+)\/(\S+)$/;
+        #}
+        foreach (`find /usr/perl5 -name 5.*| grep -v site_perl`){
+            $libperl = "/".$1."/".$2."/".$3 if /^\/(\S+)\/(\S+)\/(\S+)$/;
+            $localperl = "/".$1."/".$2."/bin/perl" if /^\/(\S+)\/(\S+)\/(\S+)$/;
+        }
         $link_info = undef;
-        foreach (`/usr/bin/kstat -m $mynic -i $mynum -s link_speed`){
-            next unless /^\s*link_speed+\s*(\d+).*$/;
-            $link_speed = $1;
+        #print "LIBPERL :".$libperl."\n";
+        #print "PERL :".$localperl."\n";
+        #print "CE = ".$mynic.$mynum."\n";
+        foreach (`$localperl -I $libperl /usr/bin/kstat -m $mynic -i $mynum -s link_speed | grep link_speed `){
+            $link_speed = $1 if /^\s*link_speed+\s*(\d+).*$/;
             #print "SPEED = ".$link_speed."\n";
             if ($link_speed =~ /^0$/ ) {
                 $link_info = $link_info."10 Mb/s";
@@ -152,9 +165,8 @@ sub doInventory {
                 $link_info = $link_info."ERROR";
             }
         }
-        foreach (`/usr/bin/kstat -m $mynic -i $mynum -s link_duplex`){
-            next unless /^\s*link_duplex+\s*(\d+).*$/;
-            $link_duplex = $1;
+        foreach (`$localperl -I $libperl /usr/bin/kstat -m $mynic -i $mynum -s link_duplex | grep link_duplex `){
+            $link_duplex = $1 if /^\s*link_duplex+\s*(\d+).*$/;
             if ($link_duplex =~ /2/ ) {
                 $link_info = $link_info." FDX";
             }elsif ($link_duplex =~ /1/) {
@@ -166,9 +178,8 @@ sub doInventory {
             }
         }
 
-        foreach (`/usr/bin/kstat -m $mynic -i $mynum -s cap_autoneg`){
-            next unless /^\s*cap_autoneg+\s*(\d+).*$/;
-            $link_auto = $1;
+        foreach (`$localperl -I $libperl /usr/bin/kstat -m $mynic -i $mynum -s cap_autoneg | grep cap_autoneg `){
+            $link_auto = $1 if /^\s*cap_autoneg+\s*(\d+).*$/;
             if ($link_auto =~ /1/ ) {
                 $link_info = $link_info." AUTOSPEED ON";
             }elsif ($link_auto =~ /0/) {
@@ -250,17 +261,19 @@ sub doInventory {
 
     }
 
-    if( can_run("zonename") ) {
-        $zone=`zonename`;
-    }else{
+    if ( $OSLevel =~ /5.8/ ){
         $zone = "global";
+    }else{
+        foreach (`zoneadm list -p`){
+            $zone=$1 if /^0:([a-z]+):.*$/;
+        }
     }
 
     foreach (`netstat -rn`){
         $ipgateway=$1 if /^default\s+(\S+)/i;
     }
     #print "Nom :".$zone."*************************\n";
-    if ($zone eq "global" ) {
+    if ($zone){
         foreach (`ifconfig -a`){
             $description = $1 if /^(\S+):/; # Interface name
             $ipaddress = $1 if /inet\s+(\S+)/i;
