@@ -6,7 +6,6 @@ use warnings;
 use constant KEY_WOW64_64KEY => 0x100;
 
 use English qw(-no_match_vars);
-use Win32;
 use Win32::TieRegistry (
     Delimiter   => '/',
     ArrayValues => 0,
@@ -14,7 +13,6 @@ use Win32::TieRegistry (
 );
 
 use FusionInventory::Agent::Task::Inventory::OS::Win32;
-use FusionInventory::Agent::Tools;
 
 # the CPU description in WMI is false, we use the registry instead
 # Hardware\Description\System\CentralProcessor\1
@@ -51,12 +49,33 @@ sub doInventory {
     my $logger = $params->{logger};
 
     my $serial;
-    my $id;
     my $speed;
 
     my $vmsystem;
 
-    my $dmidecodeCpu = getCpusFromDmidecode();
+    my @dmidecodeCpu;
+    if (can_run("dmidecode")) {
+        my $in;
+        foreach (`dmidecode`) {
+            if ($in && /^Handle/)  {
+                push @dmidecodeCpu, {serial => $serial, speed => $speed};
+                $in = 0;
+            }
+
+            if (/^Handle.*type 4,/) {
+                $in = 1 
+            } elsif ($in) {
+                $speed = $1 if /Max Speed:\s+(\d+)\s+MHz/i;
+                $speed = $1*1000 if /Max Speed:\s+(\w+)\s+GHz/i;
+                $serial = $1 if /ID:\s+(.*)/i;
+#                Core Count: 2
+#                Core Enabled: 2
+#                Thread Count: 2
+            }
+        }
+    }
+
+
 
     my $cpuId = 0;
     foreach my $Properties (getWmiProperties('Win32_Processor', qw/
@@ -70,9 +89,8 @@ sub doInventory {
         my $description = $info->{Identifier};
         my $name = $info->{ProcessorNameString};
         my $manufacturer = $info->{VendorIdentifier};
-        my $id = $dmidecodeCpu->[$cpuId]->{ID} || $Properties->{ProcessorId};
-        my $serial = $dmidecodeCpu->[$cpuId]->{SERIAL};
-        my $speed = $dmidecodeCpu->[$cpuId]->{SPEED} || $Properties->{MaxClockSpeed};
+        my $serial = $dmidecodeCpu[$cpuId]->{serial} || $Properties->{ProcessorId};
+        my $speed = $dmidecodeCpu[$cpuId]->{speed} || $Properties->{MaxClockSpeed};
 
         if ($manufacturer) {
             $manufacturer =~ s/Genuine//;
@@ -87,18 +105,19 @@ sub doInventory {
         if ($name) {
             $name =~ s/^\s+//;
             $name =~ s/\s+$//;
-
-            $vmsystem = "QEMU"if $name =~ /QEMU/i;
-
-            if ($name =~ /([\d\.]+)s*(GHZ)/i) {
-                $speed = {
-                    ghz => 1000,
-                    mhz => 1,
-                }->{lc($2)}*$1;
-            }
-
         }
 
+        $vmsystem = "QEMU"if $name =~ /QEMU/i;
+
+        if ($name =~ /([\d\.]+)s*(GHZ)/i) {
+            $speed = {
+               ghz => 1000,
+               mhz => 1,
+            }->{lc($2)}*$1;
+        }
+
+
+
         $inventory->addCPU({
 #           CACHE => $cache,
             CORE => $core,
@@ -106,8 +125,7 @@ sub doInventory {
             NAME => $name,
             MANUFACTURER => $manufacturer,
             SERIAL => $serial,
-            SPEED => $speed,
-	    ID => $id
+            SPEED => $speed
         });
 
         $cpuId++;
