@@ -11,7 +11,6 @@ use English qw(-no_match_vars);
 use Win32;
 use Win32::OLE('in');
 use Win32::OLE::Variant;
-use FusionInventory::Agent::Tools::Win32;
 use Win32::TieRegistry (
     Delimiter   => '/',
     ArrayValues => 0,
@@ -20,8 +19,6 @@ use Win32::TieRegistry (
 
 use FusionInventory::Agent::Task::Inventory::OS::Win32;
 
-my $seen = {};
-
 sub isInventoryEnabled {
     return 1;
 }
@@ -62,14 +59,13 @@ sub processSoftwares {
     foreach my $rawGuid ( keys %$softwares ) {
         my $data = $softwares->{$rawGuid};
         next unless keys %$data;
-
+        
         my $guid = $rawGuid;
         $guid =~ s/\/$//; # drop the tailing / 
 
 # odd, found on Win2003
-        if (!$data->{'/DisplayName'} && keys %$data <= 2) {
-            next;
-        }
+        next unless keys %$data > 2;
+
 
         my $name = encodeFromRegistry($data->{'/DisplayName'});
 # Use the folder name if there is no DisplayName
@@ -90,12 +86,7 @@ sub processSoftwares {
             $noRemove = ($data->{'/NoRemove'} =~ /1/)?1:0;
         }
 
-        # Workaround for #415
-        $version =~ s/[\000-\037].*// if $version;
-
-    addSoftware(
-        inventory => $inventory,
-        fields => {
+        $inventory->addSoftware ({
             COMMENTS => $comments,
 #            FILESIZE => $filesize,
 #            FOLDER => $folder,
@@ -103,8 +94,8 @@ sub processSoftwares {
             HELPLINK => $helpLink,
             INSTALLDATE => $installDate,
             NAME => $name,
-            NO_REMOVE => $noRemove,
-            RELEASE_TYPE => $releaseType,
+            NOREMOVE => $noRemove,
+            RELEASETYPE => $releaseType,
             PUBLISHER => $publisher,
             UNINSTALL_STRING => $uninstallString,
             URL_INFO_ABOUT => $urlInfoAbout,
@@ -117,40 +108,6 @@ sub processSoftwares {
     }
 }
 
-sub processMSIE {
-    my %params = @_;
-
-    my $inventory = $params{inventory};
-    my $is64bit = $params{is64bit} || 0;
-    my $machKey = $params{machKey};
-
-        my $name = "Internet Explorer";
-    if ($is64bit) {
-        $name .= " (64bit)";
-    }
-    my $version = $params{machKey}->{"SOFTWARE/Microsoft/Internet Explorer/Version"};
-
-    addSoftware (
-        inventory => $inventory,
-        fields => {
-            FROM => "registry",
-            IS64BIT => $is64bit,
-            NAME => $name,
-            VERSION => $version,
-        PUBLISHER => "Microsoft Corporation"
-        }
-    )
-}
-
-sub addSoftware {
-    my %params = @_;
-
-    return if $seen->{$params{fields}->{NAME}}->{$params{fields}->{IS64BIT}}{$params{fields}->{VERSION} || '_undef_'}++;
-
-    $params{inventory}->addSoftware ($params{fields});
-
-}
-
 sub doInventory {
     my $params = shift;
 
@@ -163,8 +120,16 @@ sub doInventory {
 
     my $Config;
 
+    my $is64bit;
+    foreach my $Properties (getWmiProperties('Win32_Processor', qw/
+        AddressWidth
+    /)) {
+        if ($Properties->{AddressWidth} eq 64) {
+            $is64bit = 1;
+        }
+    }
 
-    if (is64bit()) {
+    if ($is64bit) {
 
         # I don't know why but on Vista 32bit, KEY_WOW64_64KEY is able to read
         # 32bit entries. This is not the case on Win2003 and if I correctly
@@ -178,28 +143,15 @@ sub doInventory {
             $machKey64bit->{"SOFTWARE/Microsoft/Windows/CurrentVersion/Uninstall"};
         processSoftwares({ inventory => $inventory, softwares => $softwares, is64bit => 1});
 
-    processMSIE(
-        machKey => $machKey64bit,
-        inventory => $inventory,
-        is64bit => 1,
-    );
-
-
         my $machKey32bit = $Registry->Open('LMachine', {
             Access => KEY_READ | KEY_WOW64_32KEY
         }) or $logger->fault("Can't open HKEY_LOCAL_MACHINE key: $EXTENDED_OS_ERROR");
 
         $softwares=
             $machKey32bit->{"SOFTWARE/Microsoft/Windows/CurrentVersion/Uninstall"};
+
         processSoftwares({ inventory => $inventory, softwares => $softwares, is64bit => 0});
 
-    processMSIE(
-        machKey => $machKey32bit,
-        inventory => $inventory,
-        is64bit => 0,
-    );
-
-
     } else {
         my $machKey = $Registry->Open('LMachine', {
             Access => KEY_READ()
@@ -207,13 +159,9 @@ sub doInventory {
 
         my $softwares=
             $machKey->{"SOFTWARE/Microsoft/Windows/CurrentVersion/Uninstall"};
+
         processSoftwares({ inventory => $inventory, softwares => $softwares, is64bit => 0});
 
-    processMSIE(
-        machKey => $machKey,
-        inventory => $inventory,
-        is64bit => 0,
-    );
     }
 
 # Copyright (c) 2009 Megagram
